EXPORTS
	??0CSsmCustomCommandInfo@@QAE@XZ @ 1 NONAME ; CSsmCustomCommandInfo::CSsmCustomCommandInfo(void)
	??0TSsmPublishSystemStateInfo@@QAE@XZ @ 2 NONAME ; TSsmPublishSystemStateInfo::TSsmPublishSystemStateInfo(void)
	??1CSsmCommandList@@UAE@XZ @ 3 NONAME ; CSsmCommandList::~CSsmCommandList(void)
	??1CSsmCommandListResourceReader@@UAE@XZ @ 4 NONAME ; CSsmCommandListResourceReader::~CSsmCommandListResourceReader(void)
	??1CSsmCommandUtilProvider@@UAE@XZ @ 5 NONAME ; CSsmCommandUtilProvider::~CSsmCommandUtilProvider(void)
	??1CSsmCustomCommandInfo@@UAE@XZ @ 6 NONAME ; CSsmCustomCommandInfo::~CSsmCustomCommandInfo(void)
	??4CSsmCustomCommandInfo@@QAEAAV0@ABV0@@Z @ 7 NONAME ; class CSsmCustomCommandInfo & CSsmCustomCommandInfo::operator=(class CSsmCustomCommandInfo const &)
	??4TSsmPublishSystemStateInfo@@QAEAAV0@ABV0@@Z @ 8 NONAME ; class TSsmPublishSystemStateInfo & TSsmPublishSystemStateInfo::operator=(class TSsmPublishSystemStateInfo const &)
	??ACSsmCommandList@@QBEPBVMSsmCommand@@H@Z @ 9 NONAME ; class MSsmCommand const * CSsmCommandList::operator[](int) const
	?AppendL@CSsmCommandList@@QAEXPAVMSsmCommand@@@Z @ 10 NONAME ; void CSsmCommandList::AppendL(class MSsmCommand *)
	?Clear@CSsmCustomCommandInfo@@QAEXXZ @ 11 NONAME ; void CSsmCustomCommandInfo::Clear(void)
	?Clear@TSsmPublishSystemStateInfo@@QAEXXZ @ 12 NONAME ; void TSsmPublishSystemStateInfo::Clear(void)
	?ConstructAMAStarterCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@ABVTUid@@@Z @ 13 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructAMAStarterCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TUid const &)
	?ConstructCreateSwpCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@ABVTSsmSwp@@AAVTDesC16@@@Z @ 14 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructCreateSwpCommandLC(enum TCmdErrorSeverity, class TSsmSwp const &, class TDesC16 &)
	?ConstructCustomCommandCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@AAVCSsmCustomCommandInfo@@@Z @ 15 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructCustomCommandCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class CSsmCustomCommandInfo &)
	?ConstructFinaliseDrivesCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@@Z @ 16 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructFinaliseDrivesCommandLC(enum TCmdErrorSeverity)
	?ConstructLoadSupCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@HABVTSsmSupInfo@@@Z @ 17 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructLoadSupCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, int, class TSsmSupInfo const &)
	?ConstructMultipleWaitCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@J@Z @ 18 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructMultipleWaitCommandLC(long)
	?ConstructPersistHalAttributesCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@@Z @ 19 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructPersistHalAttributesCommandLC(enum TCmdErrorSeverity)
	?ConstructPowerOffCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TPowerState@@@Z @ 20 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructPowerOffCommandLC(enum TCmdErrorSeverity, enum TPowerState)
	?ConstructPublishSwpCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@ABVTSsmSwp@@@Z @ 21 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructPublishSwpCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TSsmSwp const &)
	?ConstructPublishSystemStateCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@AAVTSsmPublishSystemStateInfo@@@Z @ 22 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructPublishSystemStateCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TSsmPublishSystemStateInfo &)
	?ConstructReqSwpChangeCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@ABVTSsmSwp@@@Z @ 23 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructReqSwpChangeCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TSsmSwp const &)
	?ConstructSetPAndSKeyCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@ABVTUid@@IH@Z @ 24 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructSetPAndSKeyCommandLC(enum TCmdErrorSeverity, class TUid const &, unsigned int, int)
	?ConstructStartApplicationCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@PAVCSsmStartupProperties@@@Z @ 25 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructStartApplicationCommandLC(enum TCmdErrorSeverity, class CSsmStartupProperties *)
	?ConstructStartProcessCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@PAVCSsmStartupProperties@@@Z @ 26 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructStartProcessCommandLC(enum TCmdErrorSeverity, class CSsmStartupProperties *)
	?ConstructWaitForApparcInitCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@@Z @ 27 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructWaitForApparcInitCommandLC(enum TCmdErrorSeverity)
	?Count@CSsmCommandList@@QBEHXZ @ 28 NONAME ; int CSsmCommandList::Count(void) const
	?DeferredDelete@CSsmCommandList@@QAEXXZ @ 29 NONAME ; void CSsmCommandList::DeferredDelete(void)
	?DelayBetweenCommands@CSsmCommandList@@QBEHXZ @ 30 NONAME ; int CSsmCommandList::DelayBetweenCommands(void) const
	?Direction@TSsmPublishSystemStateInfo@@QBE?AW4TSsmDmTraverseDirection@@XZ @ 31 NONAME ; enum TSsmDmTraverseDirection TSsmPublishSystemStateInfo::Direction(void) const
	?Execute@CSsmCommandList@@QAEXHAAVTRequestStatus@@@Z @ 32 NONAME ; void CSsmCommandList::Execute(int, class TRequestStatus &)
	?ExecuteCancel@CSsmCommandList@@QAEXH@Z @ 33 NONAME ; void CSsmCommandList::ExecuteCancel(int)
	?ExternalizeL@CSsmCommandList@@QBEXAAVRWriteStream@@@Z @ 34 NONAME ; void CSsmCommandList::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@CSsmCustomCommandInfo@@QBEXAAVRWriteStream@@@Z @ 35 NONAME ; void CSsmCustomCommandInfo::ExternalizeL(class RWriteStream &) const
	?FileName@CSsmCustomCommandInfo@@QBEABV?$TBuf@$0BAA@@@XZ @ 36 NONAME ; class TBuf<256> const & CSsmCustomCommandInfo::FileName(void) const
	?GetCommandList@CSsmCommandListResourceReader@@QAEPAVCSsmCommandList@@XZ @ 37 NONAME ; class CSsmCommandList * CSsmCommandListResourceReader::GetCommandList(void)
	?GetCommandListIdsL@CSsmCommandListResourceReader@@QBEXAAV?$RArray@H@@@Z @ 38 NONAME ; void CSsmCommandListResourceReader::GetCommandListIdsL(class RArray<int> &) const
	?Initialise@CSsmCommandListResourceReader@@QAEXAAVTRequestStatus@@@Z @ 39 NONAME ; void CSsmCommandListResourceReader::Initialise(class TRequestStatus &)
	?InitialiseCancel@CSsmCommandListResourceReader@@QAEXXZ @ 40 NONAME ; void CSsmCommandListResourceReader::InitialiseCancel(void)
	?InternalizeL@CSsmCommandList@@QAEXAAVRReadStream@@AAVCSsmCommandUtilProvider@@@Z @ 41 NONAME ; void CSsmCommandList::InternalizeL(class RReadStream &, class CSsmCommandUtilProvider &)
	?InternalizeL@CSsmCustomCommandInfo@@QAEXAAVRReadStream@@@Z @ 42 NONAME ; void CSsmCustomCommandInfo::InternalizeL(class RReadStream &)
	?IsValidStateList@CSsmCommandListUtils@@SAHABVCSsmCommandList@@@Z @ 43 NONAME ; int CSsmCommandListUtils::IsValidStateList(class CSsmCommandList const &)
	?IsValidSwpList@CSsmCommandListUtils@@SAHABVCSsmCommandList@@@Z @ 44 NONAME ; int CSsmCommandListUtils::IsValidSwpList(class CSsmCommandList const &)
	?NewL@CSsmCommandList@@SAPAV1@XZ @ 45 NONAME ; class CSsmCommandList * CSsmCommandList::NewL(void)
	?NewL@CSsmCommandListResourceReader@@SAPAV1@AAVRFs@@ABVTDesC16@@AAVMSsmConditionalCallback@@@Z @ 46 NONAME ; class CSsmCommandListResourceReader * CSsmCommandListResourceReader::NewL(class RFs &, class TDesC16 const &, class MSsmConditionalCallback &)
	?NewL@CSsmCommandUtilProvider@@SAPAV1@XZ @ 47 NONAME ; class CSsmCommandUtilProvider * CSsmCommandUtilProvider::NewL(void)
	?NewLC@CSsmCommandList@@SAPAV1@XZ @ 48 NONAME ; class CSsmCommandList * CSsmCommandList::NewLC(void)
	?Ordinal@CSsmCustomCommandInfo@@QBEJXZ @ 49 NONAME ; long CSsmCustomCommandInfo::Ordinal(void) const
	?Params@CSsmCustomCommandInfo@@QBE?BVTPtrC8@@XZ @ 50 NONAME ; class TPtrC8 const CSsmCustomCommandInfo::Params(void) const
	?PrepareCommandList@CSsmCommandListResourceReader@@QAEXHABVTSsmState@@AAVTRequestStatus@@@Z @ 51 NONAME ; void CSsmCommandListResourceReader::PrepareCommandList(int, class TSsmState const &, class TRequestStatus &)
	?PrepareCommandList@CSsmCommandListResourceReader@@QAEXHABVTSsmSwp@@AAVTRequestStatus@@@Z @ 52 NONAME ; void CSsmCommandListResourceReader::PrepareCommandList(int, class TSsmSwp const &, class TRequestStatus &)
	?PrepareCommandListCancel@CSsmCommandListResourceReader@@QAEXXZ @ 53 NONAME ; void CSsmCommandListResourceReader::PrepareCommandListCancel(void)
	?Retries@CSsmCustomCommandInfo@@QBEFXZ @ 54 NONAME ; short CSsmCustomCommandInfo::Retries(void) const
	?Retries@TSsmPublishSystemStateInfo@@QBEFXZ @ 55 NONAME ; short TSsmPublishSystemStateInfo::Retries(void) const
	?Rfs@CSsmCustomCommandEnv@@UBEABVRFs@@XZ @ 56 NONAME ; class RFs const & CSsmCustomCommandEnv::Rfs(void) const
	?Set@TSsmPublishSystemStateInfo@@QAEXABVTSsmState@@W4TSsmDmTraverseDirection@@F@Z @ 57 NONAME ; void TSsmPublishSystemStateInfo::Set(class TSsmState const &, enum TSsmDmTraverseDirection, short)
	?SetDelayBetweenCommands@CSsmCommandList@@QAEXH@Z @ 58 NONAME ; void CSsmCommandList::SetDelayBetweenCommands(int)
	?SetL@CSsmCustomCommandInfo@@QAEXABVTDesC16@@JW4TCmdCustomCommandLibUnloading@@FABVTDesC8@@@Z @ 59 NONAME ; void CSsmCustomCommandInfo::SetL(class TDesC16 const &, long, enum TCmdCustomCommandLibUnloading, short, class TDesC8 const &)
	?State@TSsmPublishSystemStateInfo@@QBE?AVTSsmState@@XZ @ 60 NONAME ; class TSsmState TSsmPublishSystemStateInfo::State(void) const
	?Unloading@CSsmCustomCommandInfo@@QBE?AW4TCmdCustomCommandLibUnloading@@XZ @ 61 NONAME ; enum TCmdCustomCommandLibUnloading CSsmCustomCommandInfo::Unloading(void) const
	?Severity@CSsmCommandList@@QBE?AW4TCmdErrorSeverity@@H@Z @ 62 NONAME ; enum TCmdErrorSeverity CSsmCommandList::Severity(int) const
	?InternalizeL@CSsmCommandList@@QAEXAAVRReadStream@@@Z @ 63 NONAME ; void CSsmCommandList::InternalizeL(class RReadStream &)
	?ConstructCreateSwpCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@ABVTSsmSwp@@AAVTDesC16@@G@Z @ 64 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructCreateSwpCommandLC(enum TCmdErrorSeverity, class TSsmSwp const &, class TDesC16 &, unsigned short)
	?ConstructSetPAndSKeyCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@ABVTUid@@IHG@Z @ 65 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructSetPAndSKeyCommandLC(enum TCmdErrorSeverity, class TUid const &, unsigned int, int, unsigned short)
	?ConstructCustomCommandCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@AAVCSsmCustomCommandInfo@@G@Z @ 66 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructCustomCommandCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class CSsmCustomCommandInfo &, unsigned short)
	?ConstructAMAStarterCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@ABVTUid@@G@Z @ 67 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructAMAStarterCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TUid const &, unsigned short)
	?ConstructWaitForApparcInitCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@G@Z @ 68 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructWaitForApparcInitCommandLC(enum TCmdErrorSeverity, unsigned short)
	?ConstructPublishSwpCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@ABVTSsmSwp@@G@Z @ 69 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructPublishSwpCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TSsmSwp const &, unsigned short)
	?ConstructStartApplicationCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@PAVCSsmStartupProperties@@G@Z @ 70 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructStartApplicationCommandLC(enum TCmdErrorSeverity, class CSsmStartupProperties *, unsigned short)
	?ConstructPublishSystemStateCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@AAVTSsmPublishSystemStateInfo@@G@Z @ 71 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructPublishSystemStateCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TSsmPublishSystemStateInfo &, unsigned short)
	?ConstructLoadSupCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@HABVTSsmSupInfo@@G@Z @ 72 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructLoadSupCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, int, class TSsmSupInfo const &, unsigned short)
	?ConstructStartProcessCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@PAVCSsmStartupProperties@@G@Z @ 73 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructStartProcessCommandLC(enum TCmdErrorSeverity, class CSsmStartupProperties *, unsigned short)
	?ConstructReqSwpChangeCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@W4TCmdErrorSeverity@@W4TSsmExecutionBehaviour@@ABVTSsmSwp@@G@Z @ 74 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructReqSwpChangeCommandLC(enum TCmdErrorSeverity, enum TSsmExecutionBehaviour, class TSsmSwp const &, unsigned short)
	?ConstructMultipleWaitCommandLC@SsmCommandFactory@@SAPAVMSsmCommand@@JG@Z @ 75 NONAME ; class MSsmCommand * SsmCommandFactory::ConstructMultipleWaitCommandLC(long, unsigned short)
	?GetDataToValidateCommandlist@CSsmCommandList@@QBEXAAH0@Z @ 76 NONAME ; void CSsmCommandList::GetDataToValidateCommandlist(int &, int &) const
	?NewLC@CSsmCommandList@@SAPAV1@PBV1@PAVCSsmCommandUtilProvider@@@Z @ 77 NONAME ; class CSsmCommandList * CSsmCommandList::NewLC(class CSsmCommandList const *, class CSsmCommandUtilProvider *)

